@@ -3,7 +3,10 @@ use warnings;
 
 package MooseX::AttributeIndexes::Meta::Role;
 BEGIN {
-  $MooseX::AttributeIndexes::Meta::Role::VERSION = '1.0.1';
+  $MooseX::AttributeIndexes::Meta::Role::AUTHORITY = 'cpan:KENTNL';
+}
+{
+  $MooseX::AttributeIndexes::Meta::Role::VERSION = '1.0.2';
 }
 
 # ABSTRACT: MetaRole for AttributeIndexes.
@@ -12,7 +15,7 @@ use Moose::Role;
 
 
 sub composition_class_roles {
-    'MooseX::AttributeIndexes::Meta::Role::Composite'
+  'MooseX::AttributeIndexes::Meta::Role::Composite';
 }
 
 no Moose::Role;
@@ -28,11 +31,11 @@ MooseX::AttributeIndexes::Meta::Role - MetaRole for AttributeIndexes.
 
 =head1 VERSION
 
-version 1.0.1
+version 1.0.2
 
 =head1 METHODS
 
-=head2 composition_class_roles
+=head2 C<composition_class_roles>
 
 returns C<MooseX::AttributeIndexes::Meta::Role::Composite>
 
